/**
 * Token计数器测试
 */
import { estimateTokenCount, estimateMessagesTokenCount, } from "../utils/tokenCounter.js";
import { AIMessage, HumanMessage, SystemMessage, } from "@langchain/core/messages";
describe("Token Counter Tests", () => {
    describe("estimateTokenCount", () => {
        test("应该正确估算空字符串的token数量", () => {
            const result = estimateTokenCount("");
            expect(result).toBe(0);
        });
        test("应该正确估算短文本的token数量", () => {
            const result = estimateTokenCount("Hello world");
            // 假设token平均为4个字符
            expect(result).toBe(3);
        });
        test("应该正确估算中文文本的token数量", () => {
            const result = estimateTokenCount("你好，世界");
            // 中文通常一个字符对应一个token左右
            expect(result).toBeGreaterThan(0);
        });
        test("应该能处理长文本", () => {
            const longText = "a".repeat(1000);
            const result = estimateTokenCount(longText);
            expect(result).toBeGreaterThanOrEqual(200); // 假设token平均为4-5个字符
        });
    });
    describe("estimateMessagesTokenCount", () => {
        test("应该正确估算空消息数组的token数量", () => {
            const result = estimateMessagesTokenCount([]);
            expect(result).toBe(0);
        });
        test("应该正确估算单条消息的token数量", () => {
            const messages = [new HumanMessage("Hello world")];
            const result = estimateMessagesTokenCount(messages);
            expect(result).toBeGreaterThan(3); // 基本内容 + 消息格式开销
        });
        test("应该正确估算多条消息的token数量", () => {
            const messages = [
                new SystemMessage("You are a helpful assistant."),
                new HumanMessage("Hello"),
                new AIMessage("Hi there! How can I help you today?"),
            ];
            const result = estimateMessagesTokenCount(messages);
            expect(result).toBeGreaterThan(20); // 所有消息内容 + 消息格式开销
        });
        test("应该为每个消息添加开销", () => {
            const oneMessage = estimateMessagesTokenCount([
                new HumanMessage("Hello"),
            ]);
            const twoMessages = estimateMessagesTokenCount([
                new HumanMessage("Hello"),
                new AIMessage("Hi"),
            ]);
            // 两条消息的token应该大于单条消息的两倍（因为每条消息有固定开销）
            expect(twoMessages).toBeGreaterThan(oneMessage + 1);
        });
    });
});
