/**
 * 文档加载器模块
 *
 * 用于加载各种格式的文档，并将其分割成适合向量化的小块
 */
import { Document } from "@langchain/core/documents";
/**
 * 文档加载器配置
 */
export interface DocumentLoaderConfig {
    /** 块大小 */
    chunkSize?: number;
    /** 块重叠量 */
    chunkOverlap?: number;
    /** 分割器类型 */
    splitterType?: "character" | "token" | "markdown" | "recursive";
}
/**
 * 基础文档加载接口，提供扩展点
 */
export interface DocumentLoader {
    /** 加载文档 */
    load(): Promise<Document[]>;
}
/**
 * 分割文档
 * @param docs 文档数组
 * @param config 分割配置
 * @returns 分割后的文档片段
 */
export declare function splitDocuments(docs: Document[], config?: DocumentLoaderConfig): Promise<Document[]>;
/**
 * 从文本字符串创建并分割文档
 * @param text 文本字符串
 * @param metadata 元数据
 * @param config 分割配置
 * @returns 分割后的文档片段
 */
export declare function createAndSplitDocument(text: string, metadata?: Record<string, any>, config?: DocumentLoaderConfig): Promise<Document[]>;
/**
 * 加载和分割文档辅助函数
 * @param loader 文档加载器
 * @param config 分割配置
 * @returns 分割后的文档片段
 */
export declare function loadAndSplitDocuments(loader: DocumentLoader, config?: DocumentLoaderConfig): Promise<Document[]>;
