/**
 * RAG构建器模块
 *
 * 用于简化RAG应用的构建过程
 */
import { Document } from "@langchain/core/documents";
import { RAGConfig, LLMConfig } from "../types.js";
/**
 * RAG构建器类
 *
 * 用于构建检索增强生成系统
 */
export declare class RAGBuilder {
    private documents;
    private vectorStore;
    private llmConfig?;
    private ragConfig?;
    private chain;
    /**
     * 添加文档到RAG系统
     * @param docs 文档数组
     * @returns 当前RAG构建器实例
     */
    addDocuments(docs: Document[]): RAGBuilder;
    /**
     * 配置大语言模型
     * @param config LLM配置
     * @returns 当前RAG构建器实例
     */
    withLLM(config: LLMConfig): RAGBuilder;
    /**
     * 配置RAG系统参数
     * @param config RAG配置
     * @returns 当前RAG构建器实例
     */
    withRAGConfig(config: RAGConfig): RAGBuilder;
    /**
     * 构建RAG系统
     * @returns 当前RAG构建器实例
     */
    build(): Promise<RAGBuilder>;
    /**
     * 查询RAG系统
     * @param query 查询字符串
     * @returns 查询结果
     */
    query(query: string): Promise<string>;
    /**
     * 查询RAG系统(流式响应)
     * @param query 查询字符串
     * @returns 查询结果流
     */
    streamingQuery(query: string): Promise<AsyncIterable<string>>;
}
