/**
 * 公共类型定义文件
 */
/**
 * 模型提供商类型
 */
export declare enum ModelProvider {
    OPENAI = "openai",
    AZURE_OPENAI = "azure_openai",
    ANTHROPIC = "anthropic",
    LOCAL = "local"
}
/**
 * LLM配置接口
 */
export interface LLMConfig {
    /** 模型提供商 */
    provider: ModelProvider;
    /** 模型名称 */
    modelName: string;
    /** API密钥 */
    apiKey: string;
    /** 温度参数，控制随机性 (0-1) */
    temperature?: number;
    /** 其他配置参数 */
    [key: string]: any;
}
/**
 * RAG配置接口
 */
export interface RAGConfig {
    /** 向量存储类型 */
    vectorStoreType: "memory" | "pinecone" | "qdrant" | "chroma" | string;
    /** 嵌入模型名称 */
    embeddingModelName: string;
    /** 向量存储配置 */
    vectorStoreConfig?: Record<string, any>;
    /** 块大小(分割文档时) */
    chunkSize?: number;
    /** 块重叠(分割文档时) */
    chunkOverlap?: number;
}
/**
 * 向量检索结果接口
 */
export interface VectorSearchResult {
    /** 文档内容 */
    content: string;
    /** 相似度得分 */
    score: number;
    /** 元数据 */
    metadata?: Record<string, any>;
}
/**
 * Agent工具接口
 */
export interface AgentTool {
    /** 工具名称 */
    name: string;
    /** 工具描述 */
    description: string;
    /** 工具执行函数 */
    func: (input: any) => Promise<any>;
    /** 工具参数模式 */
    schema?: Record<string, any>;
}
