/**
 * 大模型健康检查工具
 *
 * 用于验证API连接和模型可用性
 */
import { ModelProvider, LLMConfig } from "../types.js";
/**
 * 健康检查结果
 */
export interface HealthCheckResult {
    /** 是否通过检查 */
    success: boolean;
    /** 延迟（毫秒） */
    latencyMs?: number;
    /** 错误信息 */
    error?: string;
    /** 额外信息 */
    info?: Record<string, any>;
    /** 建议（如有） */
    suggestion?: string;
}
/**
 * 执行LLM模型健康检查
 * @param config LLM配置
 * @returns 健康检查结果
 */
export declare function checkLLMHealth(config: LLMConfig): Promise<HealthCheckResult>;
/**
 * 执行嵌入模型健康检查
 * @param provider 模型提供商
 * @param apiKey API密钥
 * @param modelName 模型名称
 * @returns 健康检查结果
 */
export declare function checkEmbeddingHealth(provider: ModelProvider, apiKey: string, modelName?: string): Promise<HealthCheckResult>;
