/**
 * 模型检测工具
 *
 * 用于检测环境中可用的大模型和嵌入模型
 */
import { ModelProvider } from "../types.js";
/**
 * 模型可用性检测结果
 */
export interface ModelDetectionResult {
    /** 是否可用 */
    available: boolean;
    /** 详细信息 */
    details?: string;
    /** 检测到的token限制 */
    tokenLimit?: number;
}
/**
 * 检测OpenAI模型是否可用
 * @param apiKey OpenAI API密钥
 * @returns 检测结果
 */
export declare function detectOpenAIModels(apiKey: string): Promise<Record<string, ModelDetectionResult>>;
/**
 * 检测本地模型是否可用
 * @returns 检测结果
 */
export declare function detectLocalModels(): Promise<Record<string, ModelDetectionResult>>;
/**
 * 检测所有可用的模型
 * @param providers 要检测的提供商列表
 * @param apiKeys API密钥映射
 * @returns 检测结果
 */
export declare function detectAvailableModels(providers?: ModelProvider[], apiKeys?: Record<string, string>): Promise<Record<ModelProvider, Record<string, ModelDetectionResult>>>;
