/**
 * 模型加载器工具类
 *
 * 提供加载不同类型LLM模型和嵌入模型的工具函数
 */
import { ChatOpenAI } from "@langchain/openai";
import { OpenAIEmbeddings } from "@langchain/openai";
import { LLMConfig, ModelProvider } from "../types.js";
/**
 * 加载LLM模型
 * @param config 模型配置
 * @returns 返回LLM模型实例
 */
export declare function loadLLM(config: LLMConfig): ChatOpenAI<import("@langchain/openai").ChatOpenAICallOptions>;
/**
 * 加载嵌入模型
 * @param provider 模型提供商
 * @param apiKey API密钥
 * @param modelName 模型名称
 * @returns 返回嵌入模型实例
 */
export declare function loadEmbeddingModel(provider: ModelProvider, apiKey: string, modelName?: string): OpenAIEmbeddings;
