/**
 * 提示模板构建工具
 *
 * 用于简化提示模板的创建过程
 */
import { ChatPromptTemplate } from "@langchain/core/prompts";
/**
 * 提示模板构建器
 *
 * 简化ChatPromptTemplate的创建过程
 */
export declare class PromptBuilder {
    private messages;
    /**
     * 添加系统提示
     * @param text 系统提示文本
     * @returns 当前构建器实例
     */
    addSystemMessage(text: string): PromptBuilder;
    /**
     * 添加人类提示
     * @param text 人类提示模板文本
     * @returns 当前构建器实例
     */
    addHumanMessage(text: string): PromptBuilder;
    /**
     * 添加AI提示
     * @param text AI提示模板文本
     * @returns 当前构建器实例
     */
    addAIMessage(text: string): PromptBuilder;
    /**
     * 添加消息占位符
     * @param variableName 变量名称
     * @returns 当前构建器实例
     */
    addMessagesPlaceholder(variableName: string): PromptBuilder;
    /**
     * 添加原始消息
     * @param message 原始消息对象
     * @returns 当前构建器实例
     */
    addMessage(message: any): PromptBuilder;
    /**
     * 添加示例对话
     * @param humanText 人类消息
     * @param aiText AI回复
     * @returns 当前构建器实例
     */
    addExampleDialog(humanText: string, aiText: string): PromptBuilder;
    /**
     * 构建聊天提示模板
     * @returns 聊天提示模板
     */
    build(): ChatPromptTemplate;
}
/**
 * 创建RAG提示模板
 * @param systemPrompt 系统提示（可选）
 * @returns 聊天提示模板
 */
export declare function createRAGPromptTemplate(systemPrompt?: string): ChatPromptTemplate;
/**
 * 创建Agent提示模板
 * @param systemPrompt 系统提示（可选）
 * @returns 聊天提示模板
 */
export declare function createAgentPromptTemplate(systemPrompt?: string): ChatPromptTemplate;
/**
 * 创建聊天提示模板
 * @param systemPrompt 系统提示（可选）
 * @returns 聊天提示模板
 */
export declare function createChatPromptTemplate(systemPrompt?: string): ChatPromptTemplate;
/**
 * 创建翻译提示模板
 * @param targetLanguage 目标语言
 * @returns 聊天提示模板
 */
export declare function createTranslationPromptTemplate(targetLanguage: string): ChatPromptTemplate;
/**
 * 创建内容提取提示模板
 * @returns 聊天提示模板
 */
export declare function createExtractionPromptTemplate(): ChatPromptTemplate;
