# 项目介绍

## 项目背景

随着大语言模型（LLM）技术的快速发展，越来越多的开发者希望将其集成到自己的应用中。然而，直接与各种 LLM API 交互涉及许多复杂性：

- 不同提供商的 API 接口各不相同
- 构建 RAG（检索增强生成）系统需要处理文档加载、分割、向量存储等步骤
- 实现 Agent 需要定义工具、处理工具调用、管理执行流程等

`llm-nodejs-toolkit`正是为了解决这些问题而生，它提供了一套统一的、简单易用的 API，帮助开发者快速构建基于大语言模型的应用。

## 核心架构

`llm-nodejs-toolkit`采用模块化的架构设计，主要包含以下组件：

### 1. 核心模块

- **RAG 模块**：负责处理文档加载、分割、向量化、检索等功能，提供统一的查询接口
- **Agent 模块**：封装了智能代理的构建和执行逻辑，支持工具定义和调用
- **Chat 模块**：提供聊天应用的基本功能，包括消息历史管理、流式输出等

### 2. 工具模块

- **模型加载器**：统一加载不同提供商的 LLM 和嵌入模型
- **Token 计数器**：估算文本和消息的 token 数量
- **模型检测器**：检测环境中可用的模型
- **健康检查**：验证 API 连接和模型可用性
- **提示模板构建器**：简化提示模板的创建过程

## 技术栈

`llm-nodejs-toolkit`基于以下技术栈构建：

- **语言**：TypeScript
- **模块系统**：ESM（ECMAScript 模块）
- **包管理器**：pnpm
- **核心依赖**：
  - LangChain：提供了大语言模型应用的基础框架
  - @langchain/openai：OpenAI 模型集成
  - @langchain/community：社区贡献的各种集成
  - @langchain/core：LangChain 核心组件
  - zod：用于 Schema 验证

## 工作原理

### RAG（检索增强生成）

RAG 是一种结合了检索系统和生成式 AI 的技术，让大语言模型能够基于特定文档回答问题：

1. **文档处理**：加载文档，然后将其分割成适当大小的块
2. **生成嵌入**：使用嵌入模型将文档块转换为向量
3. **向量存储**：将向量和对应的文档块存储在向量数据库中
4. **查询过程**：
   - 将用户问题转换为向量
   - 从向量数据库中检索最相关的文档块
   - 将检索到的文档块作为上下文提供给大语言模型
   - 大语言模型基于上下文生成回答

### Agent（智能代理）

Agent 是能够使用工具完成复杂任务的 AI 系统：

1. **工具定义**：定义 Agent 可以使用的工具，包括工具的名称、描述和执行函数
2. **推理过程**：
   - Agent 接收用户输入
   - 分析输入内容，决定是否需要使用工具
   - 选择合适的工具，生成工具调用参数
   - 执行工具调用，获取结果
   - 基于工具结果生成回复或决定下一步行动
3. **执行结果**：返回最终生成的回答给用户

### Chat（聊天）

聊天功能是构建对话式 AI 应用的基础：

1. **初始化**：设置系统提示、历史记录限制等
2. **消息处理**：
   - 接收用户消息
   - 将消息与历史记录一起发送给 LLM
   - 获取 LLM 回复
   - 更新历史记录
3. **历史管理**：维护对话上下文，确保不超过 token 限制

## 与其他库的对比

与其他同类库相比，`llm-nodejs-toolkit`的优势包括：

- **中文优化**：特别针对中文应用场景进行了优化
- **简化 API**：提供了比原始 LangChain 更简洁的 API 设计
- **完整功能**：集成了 RAG、Agent、Chat 等全面功能
- **轻量级**：模块化设计，可以按需引入，减少不必要的依赖

## 使用场景

`llm-nodejs-toolkit`适用于各种基于大语言模型的应用场景，例如：

- **智能客服**：构建能够回答用户问题的客服机器人
- **文档助手**：创建能够回答特定文档内容问题的助手
- **智能代理**：开发能够执行特定任务的自动化代理
- **聊天机器人**：实现具有记忆功能的对话式机器人
- **内容生成**：基于提示模板生成各种文本内容

在接下来的文档中，我们将详细介绍如何安装和使用这个工具包来构建你自己的 LLM 应用。
