/**
 * 聊天示例
 *
 * 本示例展示如何使用ChatBuilder创建一个简单的聊天应用
 * 使用方法：
 * 1. 将API_KEY替换为你的OpenAI API密钥
 * 2. 运行 npx tsx chat-example.ts
 */

import { ModelProvider, ChatBuilder } from "../src/index.js";

// 替换为你的API密钥
const API_KEY = "your-api-key";

async function main() {
  console.log("正在初始化聊天...");

  // 创建聊天应用
  const chat = new ChatBuilder()
    .withLLM({
      provider: ModelProvider.OPENAI,
      modelName: "gpt-3.5-turbo",
      apiKey: API_KEY,
      temperature: 0.7,
    })
    .withSystemPrompt(
      "你是一个友好的AI助手，擅长用简洁和友好的方式回答问题。你的回答应当简明扼要但内容全面。"
    )
    .withConfig({
      memoryMessageLimit: 5, // 记住最近5条消息
      streamingEnabled: false, // 关闭流式响应
    })
    .build();

  console.log("聊天初始化完成！");
  console.log("-------------------");

  // 模拟对话
  const questions = [
    "你好，我想了解一下什么是大语言模型？",
    "它们有什么实际应用？",
    "刚才你说到的内容生成是什么意思？",
  ];

  for (const question of questions) {
    console.log(`用户: ${question}`);
    const response = await chat.sendMessage(question);
    console.log(`助手: ${response}`);
    console.log("-------------------");
  }

  // 查看历史消息
  console.log("对话历史记录:");
  const history = chat.getHistory();
  console.log(`共有${history.length}条消息`);
}

main().catch((error) => {
  console.error("出错了:", error);
});
